[nongnu] main 042974e: * README.org: Fix typos and awkward wording.

2021-09-04 Thread Eli Zaretskii
branch: main
commit 042974e358d771a5df35baafd270ea5663da9e89
Author: Eli Zaretskii 
Commit: Eli Zaretskii 

* README.org: Fix typos and awkward wording.
---
 README.org | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/README.org b/README.org
index ec40534..715b9d2 100644
--- a/README.org
+++ b/README.org
@@ -72,16 +72,16 @@ to do:
 * Using packages in-place
 
 The packages can be installed and used in-place.  First you need to make
-sure the package(s) you can about are placed in the =packages= subdirectory,
-e.g. with =make worktrees=, and then you can to add that =.../packages=
-to your =package-directory-list=.  And once that is done you can do:
+sure the package(s) you care about are placed in the =packages= subdirectory,
+e.g. with =make worktrees=, and then you can add that =.../packages= to your
+=package-directory-list=.  And once that is done, you can do:
 
 #+begin_src sh
 make packages/[PKG]
 #+end_src
 
 to create the =[PKG]-pkg.el= and =[PKG]-autoloads.el= file as well as compile
-all the ELisp files in that package.  You can also do that on all the
+all the ELisp files in that package.  You can also do that for all the
 packages with:
 
 #+begin_src sh



[elpa] master 9651cc6: Use "git worktree list" in archive-contents.el

2018-04-12 Thread Eli Zaretskii
branch: master
commit 9651cc682f02ff685dac840c51dd16f40fd0e927
Author: Eli Zaretskii <e...@gnu.org>
Commit: Eli Zaretskii <e...@gnu.org>

Use "git worktree list" in archive-contents.el

* admin/archive-contents.el (archive--use-worktree-p): Use "git
worktree list", as "--help" pops up the system Web browser on
MS-Windows.
---
 admin/archive-contents.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/admin/archive-contents.el b/admin/archive-contents.el
index 322eef9..9952469 100644
--- a/admin/archive-contents.el
+++ b/admin/archive-contents.el
@@ -704,7 +704,7 @@ If WITH-CORE is non-nil, it means we manage :core packages 
as well."
 (setq archive--use-worktree
   (list
(ignore-errors
- (zerop (call-process "git" nil nil nil "worktree" "--help"))
+ (zerop (call-process "git" nil nil nil "worktree" "list"))
   (car archive--use-worktree))
 
 (defun archive--external-package-sync (name)



[elpa] master fc7faa2: Don't rely on UTF-8 locale when talking to subordinate Emacs

2016-01-06 Thread Eli Zaretskii
branch: master
commit fc7faa28a563521cc086f239d2e3aa4b726c6d51
Author: Eli Zaretskii <e...@gnu.org>
Commit: Eli Zaretskii <e...@gnu.org>

Don't rely on UTF-8 locale when talking to subordinate Emacs

* packages/async/async.el (async--receive-sexp)
(async-batch-invoke): Bind coding-system-for-write to utf-8-unix.
(async-start): Bind coding-system-for-read to utf-8-unix.
---
 packages/async/async.el |   35 +--
 1 files changed, 21 insertions(+), 14 deletions(-)

diff --git a/packages/async/async.el b/packages/async/async.el
index 20a2f17..2cb9488 100644
--- a/packages/async/async.el
+++ b/packages/async/async.el
@@ -121,7 +121,9 @@ as follows:
 
 (defun async--receive-sexp ( stream)
   (let ((sexp (decode-coding-string (base64-decode-string
- (read stream)) 'utf-8-unix)))
+ (read stream)) 'utf-8-unix))
+   ;; Parent expects UTF-8 encoded text.
+   (coding-system-for-write 'utf-8-unix))
 (if async-debug
 (message "Received sexp {{{%s}}}" (pp-to-string sexp)))
 (setq sexp (read sexp))
@@ -147,18 +149,21 @@ as follows:
 
 (defun async-batch-invoke ()
   "Called from the child Emacs process' command-line."
-  (setq async-in-child-emacs t
-debug-on-error async-debug)
-  (if debug-on-error
-  (prin1 (funcall
-  (async--receive-sexp (unless async-send-over-pipe
- command-line-args-left
-(condition-case err
-(prin1 (funcall
-(async--receive-sexp (unless async-send-over-pipe
-   command-line-args-left
-  (error
-   (prin1 (list 'async-signal err))
+  ;; Make sure 'message' and 'prin1' encode stuff in UTF-8, as parent
+  ;; process expects.
+  (let ((coding-system-for-write 'utf-8-unix))
+(setq async-in-child-emacs t
+ debug-on-error async-debug)
+(if debug-on-error
+   (prin1 (funcall
+   (async--receive-sexp (unless async-send-over-pipe
+  command-line-args-left
+  (condition-case err
+ (prin1 (funcall
+ (async--receive-sexp (unless async-send-over-pipe
+command-line-args-left
+   (error
+(prin1 (list 'async-signal err)))
 
 (defun async-ready (future)
   "Query a FUTURE to see if the ready is ready -- i.e., if no blocking
@@ -263,7 +268,9 @@ returned except that it yields no value (since the value is
 passed to FINISH-FUNC).  Call `async-get' on such a future always
 returns nil.  It can still be useful, however, as an argument to
 `async-ready' or `async-wait'."
-  (let ((sexp start-func))
+  (let ((sexp start-func)
+   ;; Subordinate Emacs will send text encoded in UTF-8.
+   (coding-system-for-read 'utf-8-unix))
 (setq async--procvar
   (async-start-process
"emacs" (file-truename



[elpa] master 2a1c295: Support reading debbugs email exchange with Rmail

2015-11-14 Thread Eli Zaretskii
branch: master
commit 2a1c2959715430bce57bbaf7b1ee7a91ab16d82a
Author: Eli Zaretskii <e...@gnu.org>
Commit: Eli Zaretskii <e...@gnu.org>

Support reading debbugs email exchange with Rmail

* packages/debbugs/debbugs-gnu.el: Version: bump to 0.8.
(debbugs-gnu-mail-backend): New defcustom.
(debbugs-read-emacs-bug-with-rmail): New function.
(debbugs-gnu-select-report): Call it if debbugs-gnu-mail-backend
is set to use Rmail.

* packages/debbugs/debbugs-ug.texi (Tabulated Lists): Describe the
new option 'debbugs-gnu-mail-backend'.
---
 packages/debbugs/debbugs-gnu.el  |   79 +++--
 packages/debbugs/debbugs-ug.info |   31 +--
 packages/debbugs/debbugs-ug.texi |   17 ++--
 3 files changed, 97 insertions(+), 30 deletions(-)

diff --git a/README b/README
index acc42e4..be8d5b2 100644
--- a/README
+++ b/README
@@ -92,11 +92,24 @@ merge -s subtree from the upstream branch.
 
 In the `external' case, the copy of the code is not kept here but in the
 `externals/pkg' branch in the `elpa' repository.
+
 You can check out all the external packages into the `packages' directory
 with the command:
 
make externals
 
+You can check out a specific external PACKAGE into the `packages'
+directory with these commands:
+
+   cd packages
+   git clone --reference .. --single-branch --branch externals/PACKAGE 
git://git.sv.gnu.org/srv/git/emacs/elpa PACKAGE
+
+If you already have a packages/PACKAGE directory with a previous
+checkout, you can update it like this:
+
+   cd packages/PACKAGE
+   git pull
+
 ** Public incubation
 
 If you want to develop a package publicly prior to its first release (to
diff --git a/packages/debbugs/debbugs-gnu.el b/packages/debbugs/debbugs-gnu.el
index 210554f..bada55b 100644
--- a/packages/debbugs/debbugs-gnu.el
+++ b/packages/debbugs/debbugs-gnu.el
@@ -6,7 +6,7 @@
 ;; Michael Albinus <michael.albi...@gmx.org>
 ;; Keywords: comm, hypermedia, maint
 ;; Package: debbugs
-;; Version: 0.7
+;; Version: 0.8
 
 ;; This file is not part of GNU Emacs.
 
@@ -89,7 +89,7 @@
 ;; submitter, and the title of the bug.  On every bug line you could
 ;; apply the following actions by the following keystrokes:
 
 ;;   RET: Show corresponding messages in Gnus
 ;;   "C": Send a control message
 ;;   "t": Mark the bug locally as tagged
 ;;   "b": Show bugs this bug is blocked by
@@ -158,6 +158,9 @@
 (autoload 'message-make-from "message")
 (autoload 'vc-dir-hide-up-to-date "vc-dir")
 (autoload 'vc-dir-mark "vc-dir")
+(autoload 'rmail-get-new-mail "rmail")
+(autoload 'rmail-show-message "rmail")
+(autoload 'rmail-summary "rmailsum")
 (defvar compilation-in-progress)
 
 (defgroup debbugs-gnu ()
@@ -237,6 +240,15 @@ suppressed bugs is toggled by 
`debbugs-gnu-toggle-suppress'."
 (defface debbugs-gnu-archived '((t (:inverse-video t)))
   "Face for archived bug reports.")
 
+(defcustom debbugs-gnu-mail-backend 'gnus
+  "*The email backend to use for reading bug report email exchange.
+If this is 'gnus, the default, use Gnus.
+If this is 'rmail, use Rmail instead."
+  :group 'debbugs-gnu
+  :type '(choice (const :tag "Use Gnus" 'gnus)
+(const :tag "Use Rmail" 'rmail))
+  :version "25.1")
+
 (defface debbugs-gnu-new '((t (:foreground "red")))
   "Face for new reports that nobody has answered.")
 
@@ -1065,6 +1077,42 @@ interest to you."
   (set-buffer-modified-p nil)
   (special-mode))
 
+(defvar rmail-current-message)
+(defvar rmail-total-messages)
+(defvar rmail-mode-map)
+(defvar rmail-summary-mode-map)
+
+(defun debbugs-read-emacs-bug-with-rmail (id status merged)
+  "Read email exchange for debbugs bug ID.
+STATUS is the bug's status list.
+MERGED is the list of bugs merged with this one."
+  (let* ((mbox-dir (make-temp-file "debbugs" t))
+(mbox-fname (format "%s/bug_%d.mbox" mbox-dir id)))
+(debbugs-get-mbox id 'mboxmaint mbox-fname)
+(rmail mbox-fname)
+;; Download messages of all the merged bug reports and append them
+;; to the mailbox of the requested bug.
+(when merged
+  (dolist (bugno merged)
+   (let ((fn (make-temp-file "url")))
+ (debbugs-get-mbox bugno 'mboxmaint fn)
+ (rmail-get-new-mail fn)
+ (delete-file fn)
+ ;; Remove the 'unseen' attribute from all the messages we've
+ ;; just read, so that all of them appear in the summary with
+ ;; the same face.
+ (while (< rmail-current-message rmail-total-messages)
+   (rmail-show-message (1+ rmail-current-message))
+(set (make-local-variable 'debbugs-gnu-bug-number) id)
+(set (make-local-variable 'debbugs-gnu-subject)
+(format "Re: bug#%d: %s" id (cdr (assq 'subject status
+(rmail-summary)
+(define-key rmail-summary-mode-map "C" 'debbugs-gnu-send-control-message)
+(set-window-text-height nil 10)
+(other-window 1)
+(define-key rmail-mode-map "C" 'debbugs-gnu-send-control-message)
+(rmail-show-message 1)))
+
 (defun debbugs-gnu-select-report ()
   "Select the report on the current line."
   (interactive)
@@ -1072,17 +1120,22 @@ interest to you."
   (let* ((status (debbugs-gnu-current-status))
 (id (cdr (assq 'id status)))
 (merged (cdr (assq 'mergedwith status
-(gnus-read-ephemeral-emacs-bug-group
- (cons id (if (listp merged)
- merged
-   (list merged)))
- (cons (current-buffer)
-  (current-window-configuration)))
-(with-current-buffer (window-buffer (selected-win

[elpa] branch externals/chess updated (a4443ab - 9d174fe)

2014-06-19 Thread Eli Zaretskii
eliz pushed a change to branch externals/chess
in repository elpa.

  from  a4443ab   Unbreak recursive require between chess-display and 
chess-pgn.
   new  9d174fe   Fix Texinfo usage and markup in the Chess manual.

The 1 revisions listed above as new are entirely new to this
repository and will be described in separate emails.  The revisions
listed as adds were already present in the repository and have only
been added to this reference.


Summary of changes:
 ChangeLog  |6 +
 chess.texi |  804 ++--
 2 files changed, 457 insertions(+), 353 deletions(-)



[elpa] 01/01: Update README to tell how to checkout a single external package.

2014-06-17 Thread Eli Zaretskii
eliz pushed a commit to branch master
in repository elpa.

commit 6c23ac4c60be26275bc62a6ee23bb4f5cc1bbad6
Author: Eli Zaretskii e...@gnu.org
Date:   Tue Jun 17 18:35:16 2014 +0300

Update README to tell how to checkout a single external package.
---
 README |   13 +
 1 files changed, 13 insertions(+), 0 deletions(-)
@@ -89,7 +89,7 @@
 ;; apply the following actions by the following keystrokes:
 
-;;   RET: Show corresponding messages in Gnus
+;;   RET: Show corresponding messages in Gnus/Rmail
 ;;   "C": Send a control message
 ;;   "t": Mark the bug locally as tagged
